CREATE SCHEMA "RTD";

CREATE SCHEMA "RTDXLS";

CREATE TABLE "RTD"."REAL_TIME_FORMULAS" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "TABLE_SCHEMA" VARCHAR(128) NOT NULL,
    "TABLE_NAME" VARCHAR(128) NOT NULL,
    "COLUMN_NAME" VARCHAR(128) NOT NULL,
    "RTD_FORMULA" VARCHAR(255) NULL,
    "IS_DISABLED" SMALLINT NULL,
    PRIMARY KEY ("ID")
);

CREATE UNIQUE INDEX "IX_REAL_TIME_FORMULAS_COLUMN"
    ON "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME");

CREATE TABLE "RTD"."REAL_TIME_TABLES" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "TABLE_SCHEMA" VARCHAR(128) NOT NULL,
    "TABLE_NAME" VARCHAR(128) NOT NULL,
    "LOAD_CODE" STRING NULL,
    "IS_HISTORY" SMALLINT NULL,
    "IS_DISABLED" SMALLINT NULL,
    "TIME_ZONE" VARCHAR(50) NULL,
    "RTD_INSTANCE_NAME" VARCHAR(50) NULL,
    PRIMARY KEY ("ID")
);

CREATE UNIQUE INDEX "IX_REAL_TIME_TABLES_TABLE"
    ON "RTD"."REAL_TIME_TABLES" ("TABLE_SCHEMA", "TABLE_NAME");

CREATE TABLE "RTD"."FUNDAMENTALS_DAY_HISTORY_YAHOO" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "LAST_TRADE_DATE" DATE NOT NULL,
    "LAST_TRADE_TIME" TIME NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "VOLUME" INTEGER NULL,
    "DAYS_RANGE" VARCHAR(50) NULL,
    "PREV_CLOSE" DOUBLE NULL,
    "SHORT_RATIO" DOUBLE NULL,
    "YEAR_HIGH" DOUBLE NULL,
    "YEAR_LOW" DOUBLE NULL,
    "YEAR_RANGE" VARCHAR(50) NULL,
    "CHANGE_FROM_YEAR_HIGH" DOUBLE NULL,
    "CHANGE_FROM_YEAR_LOW" DOUBLE NULL,
    "PERCENT_CHANGE_FROM_YEAR_HIGH" DOUBLE NULL,
    "PERCENT_CHANGE_FROM_YEAR_LOW" DOUBLE NULL,
    "MA50" DOUBLE NULL,
    "MA200" DOUBLE NULL,
    "CHANGE_FROM_MA50" DOUBLE NULL,
    "CHANGE_FROM_MA200" DOUBLE NULL,
    "PERCENT_CHANGE_FROM_MA50" DOUBLE NULL,
    "PERCENT_CHANGE_FROM_MA200" DOUBLE NULL,
    "AVERAGE_DAILY_VOLUME" BIGINT NULL,
    "ONE_YEAR_TARGET_PRICE" DOUBLE NULL,
    "PE" DOUBLE NULL,
    "PEG" DOUBLE NULL,
    "EPS_EST_CURRENT_YEAR" DOUBLE NULL,
    "EPS_EST_NEXT_QUARTER" DOUBLE NULL,
    "EPS_EST_NEXT_YEAR" DOUBLE NULL,
    "EARNINGS_SHARE" DOUBLE NULL,
    "MARKET_CAP" VARCHAR(50) NULL,
    "DIVIDEND_YIELD" DOUBLE NULL,
    "DIVIDEND_SHARE" DOUBLE NULL,
    "EX_DIVIDEND_DATE" VARCHAR(50) NULL,
    "DIVIDEND_PAY_DATE" VARCHAR(50) NULL,
    "BOOK_VALUE" DOUBLE NULL,
    "PRICE_BOOK" DOUBLE NULL,
    "PRICE_SALES" DOUBLE NULL,
    "PRICE_EPS_EST_CURRENT_YEAR" DOUBLE NULL,
    "PRICE_EPS_EST_NEXT_YEAR" DOUBLE NULL,
    "EBITDA" VARCHAR(50) NULL,
    "COMPANY_NAME" VARCHAR(255) NULL,
    "STOCK_EXCHANGE" VARCHAR(50) NULL,
    "COMMISSION" VARCHAR(50) NULL,
    "NOTES" VARCHAR(255) NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL", "LAST_TRADE_DATE")
);


CREATE TABLE "RTD"."FUNDAMENTALS_YAHOO" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "LAST_TRADE_DATE" DATE NOT NULL,
    "LAST_TRADE_TIME" TIME NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "VOLUME" INTEGER NULL,
    "DAYS_RANGE" VARCHAR(50) NULL,
    "PREV_CLOSE" DOUBLE NULL,
    "SHORT_RATIO" DOUBLE NULL,
    "YEAR_HIGH" DOUBLE NULL,
    "YEAR_LOW" DOUBLE NULL,
    "YEAR_RANGE" VARCHAR(50) NULL,
    "CHANGE_FROM_YEAR_HIGH" DOUBLE NULL,
    "CHANGE_FROM_YEAR_LOW" DOUBLE NULL,
    "PERCENT_CHANGE_FROM_YEAR_HIGH" DOUBLE NULL,
    "PERCENT_CHANGE_FROM_YEAR_LOW" DOUBLE NULL,
    "MA50" DOUBLE NULL,
    "MA200" DOUBLE NULL,
    "CHANGE_FROM_MA50" DOUBLE NULL,
    "CHANGE_FROM_MA200" DOUBLE NULL,
    "PERCENT_CHANGE_FROM_MA50" DOUBLE NULL,
    "PERCENT_CHANGE_FROM_MA200" DOUBLE NULL,
    "AVERAGE_DAILY_VOLUME" BIGINT NULL,
    "ONE_YEAR_TARGET_PRICE" DOUBLE NULL,
    "PE" DOUBLE NULL,
    "PEG" DOUBLE NULL,
    "EPS_EST_CURRENT_YEAR" DOUBLE NULL,
    "EPS_EST_NEXT_QUARTER" DOUBLE NULL,
    "EPS_EST_NEXT_YEAR" DOUBLE NULL,
    "EARNINGS_SHARE" DOUBLE NULL,
    "MARKET_CAP" VARCHAR(50) NULL,
    "DIVIDEND_YIELD" DOUBLE NULL,
    "DIVIDEND_SHARE" DOUBLE NULL,
    "EX_DIVIDEND_DATE" VARCHAR(50) NULL,
    "DIVIDEND_PAY_DATE" VARCHAR(50) NULL,
    "BOOK_VALUE" DOUBLE NULL,
    "PRICE_BOOK" DOUBLE NULL,
    "PRICE_SALES" DOUBLE NULL,
    "PRICE_EPS_EST_CURRENT_YEAR" DOUBLE NULL,
    "PRICE_EPS_EST_NEXT_YEAR" DOUBLE NULL,
    "EBITDA" VARCHAR(50) NULL,
    "COMPANY_NAME" VARCHAR(255) NULL,
    "STOCK_EXCHANGE" VARCHAR(50) NULL,
    "COMMISSION" VARCHAR(50) NULL,
    "NOTES" VARCHAR(255) NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL")
);


CREATE TABLE "RTD"."OPTION_DAY_HISTORY_TOS" (
    "CODE" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" SMALLINT NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" SMALLINT NULL,
    "ASK_SIZE" SMALLINT NULL,
    "BID_ASK_SIZE" VARCHAR(50) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" INTEGER NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "DELTA" DOUBLE NULL,
    "GAMMA" DOUBLE NULL,
    "THETA" DOUBLE NULL,
    "VEGA" DOUBLE NULL,
    "RHO" DOUBLE NULL,
    "EXTRINSIC" DOUBLE NULL,
    "INTRINSIC" DOUBLE NULL,
    "PROBABILITY_ITM" DOUBLE NULL,
    "PROBABILITY_OTM" DOUBLE NULL,
    "PROBABILITY_TOUCH" DOUBLE NULL,
    "COVERED_RETURN" DOUBLE NULL,
    "MAX_COVERED_RETURN" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("CODE", "DATE")
);


CREATE TABLE "RTD"."OPTION_DAY_HISTORY_TWS" (
    "CODE" VARCHAR(255) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NULL,
    "LAST" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "UNDERLYING_PRICE" DOUBLE NULL,
    "MODEL_PRICE" DOUBLE NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "BID_IMPLIED_VOL" DOUBLE NULL,
    "ASK_IMPLIED_VOL" DOUBLE NULL,
    "LAST_IMPLIED_VOL" DOUBLE NULL,
    "BID_DELTA" DOUBLE NULL,
    "ASK_DELTA" DOUBLE NULL,
    "LAST_DELTA" DOUBLE NULL,
    "DELTA" DOUBLE NULL,
    "GAMMA" DOUBLE NULL,
    "THETA" DOUBLE NULL,
    "VEGA" DOUBLE NULL,
    "PV_DIVIDEND" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("CODE", "DATE")
);


CREATE TABLE "RTD"."OPTION_DAY_HISTORY_YAHOO" (
    "CODE" VARCHAR(50) NOT NULL,
    "OPTION_CODE" VARCHAR(50) NOT NULL,
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "OPTION_SYMBOL" VARCHAR(50) NOT NULL,
    "EXP_DATE" DATE NOT NULL,
    "STRIKE" DOUBLE NOT NULL,
    "TYPE" VARCHAR(50) NOT NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "MARK" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "VOLUME" INTEGER NOT NULL,
    "OPEN_INT" INTEGER NOT NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("CODE", "DATE")
);


CREATE TABLE "RTD"."OPTION_LIST_TOS" (
    "CODE" VARCHAR(50) NOT NULL,
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."OPTION_LIST_YAHOO" (
    "CODE" VARCHAR(50) NOT NULL,
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."OPTIONS_TOS" (
    "CODE" VARCHAR(50) NOT NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" SMALLINT NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" SMALLINT NULL,
    "ASK_SIZE" SMALLINT NULL,
    "BID_ASK_SIZE" VARCHAR(50) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" INTEGER NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "DELTA" DOUBLE NULL,
    "GAMMA" DOUBLE NULL,
    "THETA" DOUBLE NULL,
    "VEGA" DOUBLE NULL,
    "RHO" DOUBLE NULL,
    "EXTRINSIC" DOUBLE NULL,
    "INTRINSIC" DOUBLE NULL,
    "PROBABILITY_ITM" DOUBLE NULL,
    "PROBABILITY_OTM" DOUBLE NULL,
    "PROBABILITY_TOUCH" DOUBLE NULL,
    "COVERED_RETURN" DOUBLE NULL,
    "MAX_COVERED_RETURN" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."OPTIONS_TWS" (
    "CODE" VARCHAR(255) NOT NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "LAST" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "UNDERLYING_PRICE" DOUBLE NULL,
    "MODEL_PRICE" DOUBLE NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "BID_IMPLIED_VOL" DOUBLE NULL,
    "ASK_IMPLIED_VOL" DOUBLE NULL,
    "LAST_IMPLIED_VOL" DOUBLE NULL,
    "BID_DELTA" DOUBLE NULL,
    "ASK_DELTA" DOUBLE NULL,
    "LAST_DELTA" DOUBLE NULL,
    "DELTA" DOUBLE NULL,
    "GAMMA" DOUBLE NULL,
    "THETA" DOUBLE NULL,
    "VEGA" DOUBLE NULL,
    "PV_DIVIDEND" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."OPTIONS_YAHOO" (
    "CODE" VARCHAR(50) NOT NULL,
    "OPTION_CODE" VARCHAR(50) NOT NULL,
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "OPTION_SYMBOL" VARCHAR(50) NOT NULL,
    "EXP_DATE" DATE NOT NULL,
    "STRIKE" DOUBLE NOT NULL,
    "TYPE" VARCHAR(50) NOT NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "MARK" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "VOLUME" INTEGER NOT NULL,
    "OPEN_INT" INTEGER NOT NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."OPTION_TICK_HISTORY_TOS" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "CODE" VARCHAR(50) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" SMALLINT NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" SMALLINT NULL,
    "ASK_SIZE" SMALLINT NULL,
    "BID_ASK_SIZE" VARCHAR(50) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" INTEGER NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "DELTA" DOUBLE NULL,
    "GAMMA" DOUBLE NULL,
    "THETA" DOUBLE NULL,
    "VEGA" DOUBLE NULL,
    "RHO" DOUBLE NULL,
    "EXTRINSIC" DOUBLE NULL,
    "INTRINSIC" DOUBLE NULL,
    "PROBABILITY_ITM" DOUBLE NULL,
    "PROBABILITY_OTM" DOUBLE NULL,
    "PROBABILITY_TOUCH" DOUBLE NULL,
    "COVERED_RETURN" DOUBLE NULL,
    "MAX_COVERED_RETURN" DOUBLE NULL,
    PRIMARY KEY ("ID")
);


CREATE TABLE "RTD"."OPTION_TICK_HISTORY_TWS" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "CODE" VARCHAR(255) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "LAST" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "UNDERLYING_PRICE" DOUBLE NULL,
    "MODEL_PRICE" DOUBLE NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "BID_IMPLIED_VOL" DOUBLE NULL,
    "ASK_IMPLIED_VOL" DOUBLE NULL,
    "LAST_IMPLIED_VOL" DOUBLE NULL,
    "BID_DELTA" DOUBLE NULL,
    "ASK_DELTA" DOUBLE NULL,
    "LAST_DELTA" DOUBLE NULL,
    "DELTA" DOUBLE NULL,
    "GAMMA" DOUBLE NULL,
    "THETA" DOUBLE NULL,
    "VEGA" DOUBLE NULL,
    "PV_DIVIDEND" DOUBLE NULL,
    PRIMARY KEY ("ID")
);


CREATE TABLE "RTD"."OPTION_TICK_HISTORY_YAHOO" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "CODE" VARCHAR(50) NOT NULL,
    "OPTION_CODE" VARCHAR(50) NOT NULL,
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "OPTION_SYMBOL" VARCHAR(50) NOT NULL,
    "EXP_DATE" DATE NOT NULL,
    "STRIKE" DOUBLE NOT NULL,
    "TYPE" VARCHAR(50) NOT NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "MARK" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "VOLUME" INTEGER NOT NULL,
    "OPEN_INT" INTEGER NOT NULL,
    PRIMARY KEY ("ID")
);


CREATE TABLE "RTD"."QUOTE_DAY_HISTORY_ES" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "TRADE_PRICE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL", "DATE")
);


CREATE TABLE "RTD"."QUOTE_DAY_HISTORY_TOS" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "BID_ASK_SIZE" VARCHAR(255) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "STRENGTH_METER" VARCHAR(255) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "VOL_INDEX" DOUBLE NULL,
    "FRONT_VOL" DOUBLE NULL,
    "BACK_VOL" DOUBLE NULL,
    "WEIGHTED_BACK_VOL" DOUBLE NULL,
    "VOL_DIFF" DOUBLE NULL,
    "PUT_CALL_RATIO" DOUBLE NULL,
    "CALL_VOLUME_INDEX" DOUBLE NULL,
    "PUT_VOLUME_INDEX" DOUBLE NULL,
    "OPTION_VOLUME_INDEX" DOUBLE NULL,
    "FRONT_EXPECTED_MOVE" DOUBLE NULL,
    "BACK_EXPECTED_MOVE" DOUBLE NULL,
    "EXPECTED_MOVE_DIFF" DOUBLE NULL,
    "BETA" DOUBLE NULL,
    "HIGH52" DOUBLE NULL,
    "LOW52" DOUBLE NULL,
    "PE" DOUBLE NULL,
    "EPS" DOUBLE NULL,
    "MARKET_CAP" VARCHAR(255) NULL,
    "SHARES" BIGINT NULL,
    "DIVIDEND_YIELD" DOUBLE NULL,
    "DIVIDEND_SHARE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL", "DATE")
);


CREATE TABLE "RTD"."QUOTE_DAY_HISTORY_TWS" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NULL,
    "LAST" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL", "DATE")
);


CREATE TABLE "RTD"."QUOTE_DAY_HISTORY_VFX" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL", "DATE")
);


CREATE TABLE "RTD"."QUOTE_DAY_HISTORY_YAHOO" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "LAST_TRADE_DATE" DATE NOT NULL,
    "LAST_TRADE_TIME" TIME NOT NULL,
    "LAST" DOUBLE NOT NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "OPEN" DOUBLE NOT NULL,
    "HIGH" DOUBLE NOT NULL,
    "LOW" DOUBLE NOT NULL,
    "VOLUME" BIGINT NOT NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL", "LAST_TRADE_DATE")
);


CREATE TABLE "RTD"."QUOTE_LIST_ES" (
    "CODE" VARCHAR(50) NOT NULL,
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."QUOTE_LIST_STOCKS" (
    "CODE" VARCHAR(50) NOT NULL,
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."QUOTE_LIST_TOS" (
    "CODE" VARCHAR(50) NOT NULL,
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."QUOTE_LIST_TWS" (
    "TICK_ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "CODE" VARCHAR(50) NOT NULL,
    PRIMARY KEY ("TICK_ID")
);

CREATE UNIQUE INDEX "IX_QUOTE_LIST_TWS_CODE"
    ON "RTD"."QUOTE_LIST_TWS" ("CODE");

CREATE TABLE "RTD"."QUOTE_LIST_VFX" (
    "CODE" VARCHAR(50) NOT NULL,
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."QUOTE_LIST_YAHOO" (
    "CODE" VARCHAR(50) NOT NULL,
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."QUOTES_ES" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "TRADE_PRICE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL")
);


CREATE TABLE "RTD"."QUOTES_TOS" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATETIME" TIMESTAMP(3) NOT NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "BID_ASK_SIZE" VARCHAR(255) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "STRENGTH_METER" VARCHAR(255) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "VOL_INDEX" DOUBLE NULL,
    "FRONT_VOL" DOUBLE NULL,
    "BACK_VOL" DOUBLE NULL,
    "WEIGHTED_BACK_VOL" DOUBLE NULL,
    "VOL_DIFF" DOUBLE NULL,
    "PUT_CALL_RATIO" DOUBLE NULL,
    "CALL_VOLUME_INDEX" DOUBLE NULL,
    "PUT_VOLUME_INDEX" DOUBLE NULL,
    "OPTION_VOLUME_INDEX" DOUBLE NULL,
    "FRONT_EXPECTED_MOVE" DOUBLE NULL,
    "BACK_EXPECTED_MOVE" DOUBLE NULL,
    "EXPECTED_MOVE_DIFF" DOUBLE NULL,
    "BETA" DOUBLE NULL,
    "HIGH52" DOUBLE NULL,
    "LOW52" DOUBLE NULL,
    "PE" DOUBLE NULL,
    "EPS" DOUBLE NULL,
    "MARKET_CAP" VARCHAR(255) NULL,
    "SHARES" BIGINT NULL,
    "DIVIDEND_YIELD" DOUBLE NULL,
    "DIVIDEND_SHARE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL")
);


CREATE TABLE "RTD"."QUOTES_TWS" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "LAST" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL")
);


CREATE TABLE "RTD"."QUOTES_VFX" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL")
);


CREATE TABLE "RTD"."QUOTES_YAHOO" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "LAST_TRADE_DATETIME" TIMESTAMP(3) NOT NULL,
    "LAST_TRADE_DATE" DATE NOT NULL,
    "LAST_TRADE_TIME" TIME NOT NULL,
    "LAST" DOUBLE NOT NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "OPEN" DOUBLE NOT NULL,
    "HIGH" DOUBLE NOT NULL,
    "LOW" DOUBLE NOT NULL,
    "VOLUME" BIGINT NOT NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL")
);


CREATE TABLE "RTD"."QUOTE_TICK_HISTORY_ES" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "TRADE_PRICE" DOUBLE NULL,
    PRIMARY KEY ("ID")
);


CREATE TABLE "RTD"."QUOTE_TICK_HISTORY_TOS" (
    "ID" BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "SYMBOL" VARCHAR(50) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "BID_ASK_SIZE" VARCHAR(255) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "STRENGTH_METER" VARCHAR(255) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "VOL_INDEX" DOUBLE NULL,
    "FRONT_VOL" DOUBLE NULL,
    "BACK_VOL" DOUBLE NULL,
    "WEIGHTED_BACK_VOL" DOUBLE NULL,
    "VOL_DIFF" DOUBLE NULL,
    "PUT_CALL_RATIO" DOUBLE NULL,
    "CALL_VOLUME_INDEX" DOUBLE NULL,
    "PUT_VOLUME_INDEX" DOUBLE NULL,
    "OPTION_VOLUME_INDEX" DOUBLE NULL,
    "FRONT_EXPECTED_MOVE" DOUBLE NULL,
    "BACK_EXPECTED_MOVE" DOUBLE NULL,
    "EXPECTED_MOVE_DIFF" DOUBLE NULL,
    "BETA" DOUBLE NULL,
    "HIGH52" DOUBLE NULL,
    "LOW52" DOUBLE NULL,
    "PE" DOUBLE NULL,
    "EPS" DOUBLE NULL,
    "MARKET_CAP" VARCHAR(255) NULL,
    "SHARES" BIGINT NULL,
    "DIVIDEND_YIELD" DOUBLE NULL,
    "DIVIDEND_SHARE" DOUBLE NULL,
    PRIMARY KEY ("ID")
);


CREATE TABLE "RTD"."QUOTE_TICK_HISTORY_TWS" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "SYMBOL" VARCHAR(50) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "LAST" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    PRIMARY KEY ("ID")
);


CREATE TABLE "RTD"."QUOTE_TICK_HISTORY_VFX" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "SYMBOL" VARCHAR(50) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    PRIMARY KEY ("ID")
);


CREATE TABLE "RTD"."QUOTE_TICK_HISTORY_YAHOO" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "SYMBOL" VARCHAR(50) NOT NULL,
    "LAST_TRADE_DATETIME" TIMESTAMP(3) NOT NULL,
    "LAST_TRADE_DATE" DATE NOT NULL,
    "LAST_TRADE_TIME" TIME NOT NULL,
    "LAST" DOUBLE NOT NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "OPEN" DOUBLE NOT NULL,
    "HIGH" DOUBLE NOT NULL,
    "LOW" DOUBLE NOT NULL,
    "VOLUME" BIGINT NOT NULL,
    PRIMARY KEY ("ID")
);


CREATE TABLE "RTD"."QUOTE_TIME_HISTORY_ES" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "TRADE_PRICE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL", "DATE", "TIME")
);


CREATE TABLE "RTD"."QUOTE_TIME_HISTORY_VFX" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL", "DATE", "TIME")
);


CREATE TABLE "RTD"."QUOTE_TIME_HISTORY_YAHOO" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "LAST_TRADE_DATETIME" TIMESTAMP(3) NOT NULL,
    "LAST_TRADE_DATE" DATE NOT NULL,
    "LAST_TRADE_TIME" TIME NOT NULL,
    "LAST" DOUBLE NOT NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "OPEN" DOUBLE NOT NULL,
    "HIGH" DOUBLE NOT NULL,
    "LOW" DOUBLE NOT NULL,
    "VOLUME" BIGINT NOT NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL", "LAST_TRADE_DATETIME")
);


CREATE TABLE "RTD"."STOCKS_YAHOO" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "COMPANY_NAME" VARCHAR(255) NULL,
    "SECTOR" VARCHAR(255) NULL,
    "INDUSTRY" VARCHAR(255) NULL,
    "FULLTIME_EMPLOYEES" INTEGER NULL,
    "TRADE_START" DATE NULL,
    "TRADE_END" DATE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL")
);

insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'ID');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'CODE');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'DATETIME', '=DateTime()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'DATE', '=Date()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'TIME', '=Time()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'LAST', '=RTD("tos.rtd",,"LAST",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'LAST_X', '=RTD("tos.rtd",,"LX",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'MARK', '=RTD("tos.rtd",,"MARK",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'BID', '=RTD("tos.rtd",,"BID",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'ASK', '=RTD("tos.rtd",,"ASK",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'BID_X', '=RTD("tos.rtd",,"BX",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'ASK_X', '=RTD("tos.rtd",,"AX",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'OPEN', '=RTD("tos.rtd",,"OPEN",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'HIGH', '=RTD("tos.rtd",,"HIGH",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'LOW', '=RTD("tos.rtd",,"LOW",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'DELTA', '=RTD("tos.rtd",,"DELTA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'GAMMA', '=RTD("tos.rtd",,"GAMMA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'THETA', '=RTD("tos.rtd",,"THETA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'VEGA', '=RTD("tos.rtd",,"VEGA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'RHO', '=RTD("tos.rtd",,"RHO",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'EXTRINSIC', '=RTD("tos.rtd",,"EXTRINSIC",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'INTRINSIC', '=RTD("tos.rtd",,"INTRINSIC",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'PROBABILITY_ITM', '=RTD("tos.rtd",,"PROB_OF_EXPIRING",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'PROBABILITY_OTM', '=RTD("tos.rtd",,"PROB_OTM",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'PROBABILITY_TOUCH', '=RTD("tos.rtd",,"PROB_OF_TOUCHING",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'COVERED_RETURN', '=RTD("tos.rtd",,"COVERED_RETURN",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_TICK_HISTORY_TOS', 'MAX_COVERED_RETURN', '=RTD("tos.rtd",,"MAX_COVERED_RETURN",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'CODE');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'DATE', '=Date()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'TIME', '=Time()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'LAST', '=RTD("tos.rtd",,"LAST",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'LAST_X', '=RTD("tos.rtd",,"LX",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'MARK', '=RTD("tos.rtd",,"MARK",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'BID', '=RTD("tos.rtd",,"BID",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'ASK', '=RTD("tos.rtd",,"ASK",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'BID_X', '=RTD("tos.rtd",,"BX",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'ASK_X', '=RTD("tos.rtd",,"AX",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'OPEN', '=RTD("tos.rtd",,"OPEN",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'HIGH', '=RTD("tos.rtd",,"HIGH",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'LOW', '=RTD("tos.rtd",,"LOW",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'DELTA', '=RTD("tos.rtd",,"DELTA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'GAMMA', '=RTD("tos.rtd",,"GAMMA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'THETA', '=RTD("tos.rtd",,"THETA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'VEGA', '=RTD("tos.rtd",,"VEGA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'RHO', '=RTD("tos.rtd",,"RHO",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'EXTRINSIC', '=RTD("tos.rtd",,"EXTRINSIC",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'INTRINSIC', '=RTD("tos.rtd",,"INTRINSIC",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'PROBABILITY_ITM', '=RTD("tos.rtd",,"PROB_OF_EXPIRING",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'PROBABILITY_OTM', '=RTD("tos.rtd",,"PROB_OTM",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'PROBABILITY_TOUCH', '=RTD("tos.rtd",,"PROB_OF_TOUCHING",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'COVERED_RETURN', '=RTD("tos.rtd",,"COVERED_RETURN",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTION_DAY_HISTORY_TOS', 'MAX_COVERED_RETURN', '=RTD("tos.rtd",,"MAX_COVERED_RETURN",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") values ('RTD', 'OPTIONS_TOS', 'CODE');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'DATETIME', '=DateTime()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'DATE', '=Date()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'TIME', '=Time()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'LAST', '=RTD("tos.rtd",,"LAST",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'LAST_X', '=RTD("tos.rtd",,"LX",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'MARK', '=RTD("tos.rtd",,"MARK",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'BID', '=RTD("tos.rtd",,"BID",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'ASK', '=RTD("tos.rtd",,"ASK",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'BID_X', '=RTD("tos.rtd",,"BX",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'ASK_X', '=RTD("tos.rtd",,"AX",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'OPEN', '=RTD("tos.rtd",,"OPEN",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'HIGH', '=RTD("tos.rtd",,"HIGH",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'LOW', '=RTD("tos.rtd",,"LOW",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'DELTA', '=RTD("tos.rtd",,"DELTA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'GAMMA', '=RTD("tos.rtd",,"GAMMA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'THETA', '=RTD("tos.rtd",,"THETA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'VEGA', '=RTD("tos.rtd",,"VEGA",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'RHO', '=RTD("tos.rtd",,"RHO",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'EXTRINSIC', '=RTD("tos.rtd",,"EXTRINSIC",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'INTRINSIC', '=RTD("tos.rtd",,"INTRINSIC",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'PROBABILITY_ITM', '=RTD("tos.rtd",,"PROB_OF_EXPIRING",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'PROBABILITY_OTM', '=RTD("tos.rtd",,"PROB_OTM",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'PROBABILITY_TOUCH', '=RTD("tos.rtd",,"PROB_OF_TOUCHING",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'COVERED_RETURN', '=RTD("tos.rtd",,"COVERED_RETURN",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'OPTIONS_TOS', 'MAX_COVERED_RETURN', '=RTD("tos.rtd",,"MAX_COVERED_RETURN",[CODE])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'ID');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'SYMBOL');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'DATETIME', '=DateTime()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'DATE', '=Date()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'TIME', '=Time()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'LAST', '=RTD("tos.rtd",,"LAST",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'LAST_X', '=RTD("tos.rtd",,"LX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'MARK', '=RTD("tos.rtd",,"MARK",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'BID', '=RTD("tos.rtd",,"BID",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'ASK', '=RTD("tos.rtd",,"ASK",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'BID_X', '=RTD("tos.rtd",,"BX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'ASK_X', '=RTD("tos.rtd",,"AX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'STRENGTH_METER', '=RTD("tos.rtd",,"STRENGTH_METER",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'OPEN', '=RTD("tos.rtd",,"OPEN",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'HIGH', '=RTD("tos.rtd",,"HIGH",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'LOW', '=RTD("tos.rtd",,"LOW",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'VOL_INDEX', '=RTD("tos.rtd",,"VOL_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'FRONT_VOL', '=RTD("tos.rtd",,"FRONT_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'BACK_VOL', '=RTD("tos.rtd",,"BACK_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'WEIGHTED_BACK_VOL', '=RTD("tos.rtd",,"WEIGHTED_BACK_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'VOL_DIFF', '=RTD("tos.rtd",,"VOL_DIFF",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'PUT_CALL_RATIO', '=RTD("tos.rtd",,"PUT_CALL_RATIO",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'CALL_VOLUME_INDEX', '=RTD("tos.rtd",,"CALL_VOLUME_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'PUT_VOLUME_INDEX', '=RTD("tos.rtd",,"PUT_VOLUME_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'OPTION_VOLUME_INDEX', '=RTD("tos.rtd",,"OPTION_VOLUME_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'FRONT_EXPECTED_MOVE', '=RTD("tos.rtd",,"FRONT_EX_MOVE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'BACK_EXPECTED_MOVE', '=RTD("tos.rtd",,"BACK_EX_MOVE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'EXPECTED_MOVE_DIFF', '=RTD("tos.rtd",,"EX_MOVE_DIFF",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'BETA', '=RTD("tos.rtd",,"BETA",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'HIGH52', '=RTD("tos.rtd",,"52HIGH",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'LOW52', '=RTD("tos.rtd",,"52LOW",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'PE', '=RTD("tos.rtd",,"PE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'EPS', '=RTD("tos.rtd",,"EPS",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'MARKET_CAP', '=RTD("tos.rtd",,"MARKET_CAP",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'SHARES', '=RTD("tos.rtd",,"SHARES",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'DIVIDEND_YIELD', '=RTD("tos.rtd",,"YIELD",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'DIVIDEND_SHARE', '=RTD("tos.rtd",,"DIV",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'SYMBOL');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'DATE', '=Date()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'TIME', '=Time()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'LAST', '=RTD("tos.rtd",,"LAST",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'LAST_X', '=RTD("tos.rtd",,"LX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'MARK', '=RTD("tos.rtd",,"MARK",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'BID', '=RTD("tos.rtd",,"BID",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'ASK', '=RTD("tos.rtd",,"ASK",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'BID_X', '=RTD("tos.rtd",,"BX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'ASK_X', '=RTD("tos.rtd",,"AX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'STRENGTH_METER', '=RTD("tos.rtd",,"STRENGTH_METER",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'OPEN', '=RTD("tos.rtd",,"OPEN",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'HIGH', '=RTD("tos.rtd",,"HIGH",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'LOW', '=RTD("tos.rtd",,"LOW",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'VOL_INDEX', '=RTD("tos.rtd",,"VOL_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'FRONT_VOL', '=RTD("tos.rtd",,"FRONT_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'BACK_VOL', '=RTD("tos.rtd",,"BACK_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'WEIGHTED_BACK_VOL', '=RTD("tos.rtd",,"WEIGHTED_BACK_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'VOL_DIFF', '=RTD("tos.rtd",,"VOL_DIFF",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'PUT_CALL_RATIO', '=RTD("tos.rtd",,"PUT_CALL_RATIO",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'CALL_VOLUME_INDEX', '=RTD("tos.rtd",,"CALL_VOLUME_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'PUT_VOLUME_INDEX', '=RTD("tos.rtd",,"PUT_VOLUME_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'OPTION_VOLUME_INDEX', '=RTD("tos.rtd",,"OPTION_VOLUME_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'FRONT_EXPECTED_MOVE', '=RTD("tos.rtd",,"FRONT_EX_MOVE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'BACK_EXPECTED_MOVE', '=RTD("tos.rtd",,"BACK_EX_MOVE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'EXPECTED_MOVE_DIFF', '=RTD("tos.rtd",,"EX_MOVE_DIFF",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'BETA', '=RTD("tos.rtd",,"BETA",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'HIGH52', '=RTD("tos.rtd",,"52HIGH",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'LOW52', '=RTD("tos.rtd",,"52LOW",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'PE', '=RTD("tos.rtd",,"PE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'EPS', '=RTD("tos.rtd",,"EPS",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'MARKET_CAP', '=RTD("tos.rtd",,"MARKET_CAP",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'SHARES', '=RTD("tos.rtd",,"SHARES",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'DIVIDEND_YIELD', '=RTD("tos.rtd",,"YIELD",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'DIVIDEND_SHARE', '=RTD("tos.rtd",,"DIV",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") values ('RTD', 'QUOTES_TOS', 'SYMBOL');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'DATETIME', '=DateTime()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'DATE', '=Date()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'TIME', '=Time()');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'LAST', '=RTD("tos.rtd",,"LAST",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'LAST_X', '=RTD("tos.rtd",,"LX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'MARK', '=RTD("tos.rtd",,"MARK",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'BID', '=RTD("tos.rtd",,"BID",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'ASK', '=RTD("tos.rtd",,"ASK",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'BID_X', '=RTD("tos.rtd",,"BX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'ASK_X', '=RTD("tos.rtd",,"AX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'STRENGTH_METER', '=RTD("tos.rtd",,"STRENGTH_METER",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'OPEN', '=RTD("tos.rtd",,"OPEN",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'HIGH', '=RTD("tos.rtd",,"HIGH",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'LOW', '=RTD("tos.rtd",,"LOW",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'VOL_INDEX', '=RTD("tos.rtd",,"VOL_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'FRONT_VOL', '=RTD("tos.rtd",,"FRONT_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'BACK_VOL', '=RTD("tos.rtd",,"BACK_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'WEIGHTED_BACK_VOL', '=RTD("tos.rtd",,"WEIGHTED_BACK_VOL",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'VOL_DIFF', '=RTD("tos.rtd",,"VOL_DIFF",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'PUT_CALL_RATIO', '=RTD("tos.rtd",,"PUT_CALL_RATIO",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'CALL_VOLUME_INDEX', '=RTD("tos.rtd",,"CALL_VOLUME_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'PUT_VOLUME_INDEX', '=RTD("tos.rtd",,"PUT_VOLUME_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'OPTION_VOLUME_INDEX', '=RTD("tos.rtd",,"OPTION_VOLUME_INDEX",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'FRONT_EXPECTED_MOVE', '=RTD("tos.rtd",,"FRONT_EX_MOVE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'BACK_EXPECTED_MOVE', '=RTD("tos.rtd",,"BACK_EX_MOVE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'EXPECTED_MOVE_DIFF', '=RTD("tos.rtd",,"EX_MOVE_DIFF",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'BETA', '=RTD("tos.rtd",,"BETA",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'HIGH52', '=RTD("tos.rtd",,"52HIGH",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'LOW52', '=RTD("tos.rtd",,"52LOW",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'PE', '=RTD("tos.rtd",,"PE",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'EPS', '=RTD("tos.rtd",,"EPS",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'MARKET_CAP', '=RTD("tos.rtd",,"MARKET_CAP",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'SHARES', '=RTD("tos.rtd",,"SHARES",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'DIVIDEND_YIELD', '=RTD("tos.rtd",,"YIELD",[SYMBOL])');
insert into "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA") values ('RTD', 'QUOTES_TOS', 'DIVIDEND_SHARE', '=RTD("tos.rtd",,"DIV",[SYMBOL])');

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'REQ', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'UNDERLYING_PRICE', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'MODEL_PRICE', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'IMPLIED_VOL', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'BID_IMPLIED_VOL', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'ASK_IMPLIED_VOL', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'LAST_IMPLIED_VOL', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'BID_DELTA', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'ASK_DELTA', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'LAST_DELTA', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'DELTA', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'GAMMA', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'THETA', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'VEGA', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'PV_DIVIDEND', '=S|tik!id[TICK_ID]?pvDividend', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'REQ', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'UNDERLYING_PRICE', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'MODEL_PRICE', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'IMPLIED_VOL', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'BID_IMPLIED_VOL', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'ASK_IMPLIED_VOL', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'LAST_IMPLIED_VOL', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'BID_DELTA', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'ASK_DELTA', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'LAST_DELTA', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'DELTA', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'GAMMA', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'THETA', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'VEGA', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'PV_DIVIDEND', '=S|tik!id[TICK_ID]?pvDividend', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'REQ', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'UNDERLYING_PRICE', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'MODEL_PRICE', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'IMPLIED_VOL', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'BID_IMPLIED_VOL', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'ASK_IMPLIED_VOL', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'LAST_IMPLIED_VOL', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'BID_DELTA', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'ASK_DELTA', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'LAST_DELTA', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'DELTA', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'GAMMA', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'THETA', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'VEGA', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_TWS', 'PV_DIVIDEND', '=S|tik!id[TICK_ID]?pvDividend', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'SYMBOL', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'REQ', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'SYMBOL', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'REQ', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'SYMBOL', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'REQ', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_TWS', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'SYMBOL', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'LAST_TRADE_DATE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'LAST_TRADE_TIME', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'LAST', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'CHANGE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PERCENT_CHANGE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'OPEN', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'HIGH', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'LOW', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'VOLUME', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'DAYS_RANGE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DaysRange")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PREV_CLOSE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PreviousClose")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'SHORT_RATIO', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ShortRatio")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'YEAR_HIGH', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearHigh")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'YEAR_LOW', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearLow")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'YEAR_RANGE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearRange")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'CHANGE_FROM_YEAR_HIGH', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromYearHigh")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'CHANGE_FROM_YEAR_LOW', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromYearLow")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PERCENT_CHANGE_FROM_YEAR_HIGH', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromYearHigh")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PERCENT_CHANGE_FROM_YEAR_LOW', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromYearLow")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'MA50', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"FiftydayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'MA200', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"TwoHundredDayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'CHANGE_FROM_MA50', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromFiftyDayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'CHANGE_FROM_MA200', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromTwoHundredDayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PERCENT_CHANGE_FROM_MA50', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromFiftyDayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PERCENT_CHANGE_FROM_MA200', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromTwoHundredDayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'AVERAGE_DAILY_VOLUME', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"AverageDailyVolume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'ONE_YEAR_TARGET_PRICE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"OneYrTargetPrice")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PERatio")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PEG', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PEGRatio")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'EPS_EST_CURRENT_YEAR', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateCurrentYear")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'EPS_EST_NEXT_QUARTER', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateNextQuarter")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'EPS_EST_NEXT_YEAR', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateNextYear")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'EARNINGS_SHARE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EarningsShare")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'MARKET_CAP', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"MarketCapitalization")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'DIVIDEND_YIELD', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendYield")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'DIVIDEND_SHARE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendShare")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'EX_DIVIDEND_DATE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ExDividendDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'DIVIDEND_PAY_DATE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendPayDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'BOOK_VALUE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"BookValue")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PRICE_BOOK', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceBook")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PRICE_SALES', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceSales")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PRICE_EPS_EST_CURRENT_YEAR', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceEPSEstimateCurrentYear")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'PRICE_EPS_EST_NEXT_YEAR', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceEPSEstimateNextYear")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'EBITDA', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EBITDA")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'COMPANY_NAME', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Name")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'STOCK_EXCHANGE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"StockExchange")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'COMMISSION', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Commission")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'NOTES', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Notes")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'SYMBOL', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'LAST_TRADE_DATE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'LAST_TRADE_TIME', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'LAST', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'CHANGE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PERCENT_CHANGE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'OPEN', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'HIGH', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'LOW', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'VOLUME', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'DAYS_RANGE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DaysRange")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PREV_CLOSE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PreviousClose")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'SHORT_RATIO', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ShortRatio")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'YEAR_HIGH', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearHigh")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'YEAR_LOW', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearLow")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'YEAR_RANGE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearRange")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'CHANGE_FROM_YEAR_HIGH', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromYearHigh")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'CHANGE_FROM_YEAR_LOW', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromYearLow")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PERCENT_CHANGE_FROM_YEAR_HIGH', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromYearHigh")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PERCENT_CHANGE_FROM_YEAR_LOW', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromYearLow")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'MA50', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"FiftydayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'MA200', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"TwoHundredDayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'CHANGE_FROM_MA50', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromFiftyDayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'CHANGE_FROM_MA200', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromTwoHundredDayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PERCENT_CHANGE_FROM_MA50', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromFiftyDayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PERCENT_CHANGE_FROM_MA200', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromTwoHundredDayMovingAverage")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'AVERAGE_DAILY_VOLUME', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"AverageDailyVolume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'ONE_YEAR_TARGET_PRICE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"OneYrTargetPrice")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PERatio")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PEG', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PEGRatio")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'EPS_EST_CURRENT_YEAR', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateCurrentYear")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'EPS_EST_NEXT_QUARTER', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateNextQuarter")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'EPS_EST_NEXT_YEAR', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateNextYear")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'EARNINGS_SHARE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EarningsShare")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'MARKET_CAP', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"MarketCapitalization")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'DIVIDEND_YIELD', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendYield")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'DIVIDEND_SHARE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendShare")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'EX_DIVIDEND_DATE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ExDividendDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'DIVIDEND_PAY_DATE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendPayDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'BOOK_VALUE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"BookValue")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PRICE_BOOK', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceBook")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PRICE_SALES', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceSales")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PRICE_EPS_EST_CURRENT_YEAR', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceEPSEstimateCurrentYear")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'PRICE_EPS_EST_NEXT_YEAR', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceEPSEstimateNextYear")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'EBITDA', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EBITDA")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'COMPANY_NAME', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Name")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'STOCK_EXCHANGE', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"StockExchange")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'COMMISSION', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Commission")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'NOTES', '=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Notes")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'OPTION_CODE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionCode")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'SYMBOL', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'DATETIME', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'DATE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'TIME', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'OPTION_SYMBOL', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionSymbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'EXP_DATE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Exp")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'STRIKE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Strike")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'TYPE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Type")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'LAST', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'CHANGE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'PERCENT_CHANGE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"ChangeInPercent")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'MARK', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Mark")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'BID', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Bid")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'ASK', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Ask")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'VOLUME', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'OPEN_INT', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OpenInt")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'OPTION_CODE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionCode")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'SYMBOL', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'DATETIME', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'DATE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'TIME', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'OPTION_SYMBOL', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionSymbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'EXP_DATE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Exp")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'STRIKE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Strike")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'TYPE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Type")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'LAST', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'CHANGE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'PERCENT_CHANGE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"ChangeInPercent")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'MARK', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Mark")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'BID', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Bid")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'ASK', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Ask")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'VOLUME', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'OPEN_INT', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OpenInt")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'OPTION_CODE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionCode")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'SYMBOL', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'DATETIME', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'DATE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'TIME', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'OPTION_SYMBOL', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionSymbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'EXP_DATE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Exp")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'STRIKE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Strike")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'TYPE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Type")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'LAST', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'CHANGE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'PERCENT_CHANGE', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"ChangeInPercent")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'MARK', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Mark")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'BID', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Bid")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'ASK', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Ask")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'VOLUME', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'OPTIONS_YAHOO', 'OPEN_INT', '=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OpenInt")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'SYMBOL', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'LAST_TRADE_DATETIME', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDateTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'LAST_TRADE_DATE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'LAST_TRADE_TIME', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'LAST', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'CHANGE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'PERCENT_CHANGE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'OPEN', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'HIGH', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'LOW', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'VOLUME', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_YAHOO', 'SYMBOL', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_YAHOO', 'LAST_TRADE_DATE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_YAHOO', 'LAST_TRADE_TIME', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_YAHOO', 'LAST', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_YAHOO', 'CHANGE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_YAHOO', 'PERCENT_CHANGE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_YAHOO', 'OPEN', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_YAHOO', 'HIGH', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_YAHOO', 'LOW', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_YAHOO', 'VOLUME', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'SYMBOL', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'LAST_TRADE_DATETIME', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDateTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'LAST_TRADE_DATE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'LAST_TRADE_TIME', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'LAST', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'CHANGE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'PERCENT_CHANGE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'OPEN', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'HIGH', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'LOW', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'VOLUME', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_YAHOO', 'SYMBOL', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_YAHOO', 'LAST_TRADE_DATETIME', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDateTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_YAHOO', 'LAST_TRADE_DATE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_YAHOO', 'LAST_TRADE_TIME', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_YAHOO', 'LAST', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_YAHOO', 'CHANGE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_YAHOO', 'PERCENT_CHANGE', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_YAHOO', 'OPEN', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_YAHOO', 'HIGH', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_YAHOO', 'LOW', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_YAHOO', 'VOLUME', '=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'STOCKS_YAHOO', 'SYMBOL', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'STOCKS_YAHOO', 'COMPANY_NAME', '=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"CompanyName")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'STOCKS_YAHOO', 'SECTOR', '=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"Sector")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'STOCKS_YAHOO', 'INDUSTRY', '=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"Industry")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'STOCKS_YAHOO', 'FULLTIME_EMPLOYEES', '=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"FullTimeEmployees")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'STOCKS_YAHOO', 'TRADE_START', '=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"Start")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'STOCKS_YAHOO', 'TRADE_END', '=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"End")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_ES', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','FUNDAMENTALS_DAY_HISTORY_YAHOO','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','FUNDAMENTALS_YAHOO','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','OPTION_DAY_HISTORY_TOS','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','OPTION_DAY_HISTORY_TWS','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','OPTION_DAY_HISTORY_YAHOO','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','OPTIONS_TOS','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','OPTIONS_TWS','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','OPTIONS_YAHOO','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTE_DAY_HISTORY_ES','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTE_DAY_HISTORY_TOS','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTE_DAY_HISTORY_TWS','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTE_DAY_HISTORY_VFX','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTE_DAY_HISTORY_YAHOO','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTES_ES','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTES_TOS','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTES_TWS','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTES_VFX','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTES_YAHOO','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTE_TIME_HISTORY_ES','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTE_TIME_HISTORY_VFX','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','QUOTE_TIME_HISTORY_YAHOO','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","RTD_FORMULA","IS_DISABLED") VALUES ('RTD','STOCKS_YAHOO','LAST_UPDATE_TIMESTAMP','=TimeStamp()',NULL);

INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'FUNDAMENTALS_DAY_HISTORY_YAHOO', 'SELECT CODE AS SYMBOL FROM RTD.QUOTE_LIST_STOCKS', NULL, NULL, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'FUNDAMENTALS_YAHOO', 'SELECT CODE AS SYMBOL FROM RTD.QUOTE_LIST_STOCKS', NULL, NULL, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'OPTION_DAY_HISTORY_TOS', 'SELECT CODE FROM RTD.OPTION_LIST_TOS', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'OPTION_DAY_HISTORY_TWS', 'SELECT TICK_ID, CODE FROM RTD.QUOTE_LIST_TWS WHERE CODE LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'OPTION_DAY_HISTORY_YAHOO', 'SELECT CODE FROM RTD.OPTION_LIST_YAHOO', NULL, NULL, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'OPTIONS_TOS', 'SELECT CODE FROM RTD.OPTION_LIST_TOS', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'OPTIONS_TWS', 'SELECT TICK_ID, CODE FROM RTD.QUOTE_LIST_TWS WHERE CODE LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'OPTIONS_YAHOO', 'SELECT CODE FROM RTD.OPTION_LIST_YAHOO', NULL, NULL, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'OPTION_TICK_HISTORY_TOS', 'SELECT CODE FROM RTD.OPTION_LIST_TOS', 1, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'OPTION_TICK_HISTORY_TWS', 'SELECT TICK_ID, CODE FROM RTD.QUOTE_LIST_TWS WHERE CODE LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'OPTION_TICK_HISTORY_YAHOO', 'SELECT CODE FROM RTD.OPTION_LIST_YAHOO', 1, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_DAY_HISTORY_ES', 'SELECT CODE FROM RTD.QUOTE_LIST_ES', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TOS', 'SELECT CODE AS SYMBOL FROM RTD.QUOTE_LIST_TOS', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_DAY_HISTORY_TWS', 'SELECT TICK_ID, CODE AS SYMBOL FROM RTD.QUOTE_LIST_TWS WHERE CODE NOT LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'SELECT CODE FROM RTD.QUOTE_LIST_VFX', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_DAY_HISTORY_YAHOO', 'SELECT CODE AS SYMBOL FROM RTD.QUOTE_LIST_YAHOO', NULL, NULL, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTES_ES', 'SELECT CODE FROM RTD.QUOTE_LIST_ES', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTES_TOS', 'SELECT CODE AS SYMBOL FROM RTD.QUOTE_LIST_TOS', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTES_TWS', 'SELECT TICK_ID, CODE AS SYMBOL FROM RTD.QUOTE_LIST_TWS WHERE CODE NOT LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTES_VFX', 'SELECT CODE FROM RTD.QUOTE_LIST_VFX', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTES_YAHOO', 'SELECT CODE AS SYMBOL FROM RTD.QUOTE_LIST_YAHOO', NULL, NULL, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_TICK_HISTORY_ES', 'SELECT CODE FROM RTD.QUOTE_LIST_ES', 1, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TOS', 'SELECT CODE AS SYMBOL FROM RTD.QUOTE_LIST_TOS', 1, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_TICK_HISTORY_TWS', 'SELECT TICK_ID, CODE AS SYMBOL FROM RTD.QUOTE_LIST_TWS WHERE CODE NOT LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'SELECT CODE FROM RTD.QUOTE_LIST_VFX', 1, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_TICK_HISTORY_YAHOO', 'SELECT CODE AS SYMBOL FROM RTD.QUOTE_LIST_YAHOO', 1, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_TIME_HISTORY_ES', 'SELECT CODE FROM RTD.QUOTE_LIST_ES', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'SELECT CODE FROM RTD.QUOTE_LIST_VFX', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_TIME_HISTORY_YAHOO', 'SELECT CODE AS SYMBOL FROM RTD.QUOTE_LIST_YAHOO', NULL, 1, 'Eastern Standard Time', NULL);
INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'STOCKS_YAHOO', 'SELECT CODE AS SYMBOL FROM RTD.QUOTE_LIST_STOCKS', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."OPTION_LIST_TOS" ("CODE") VALUES ('.AAPL150117C500');
INSERT INTO "RTD"."OPTION_LIST_TOS" ("CODE") VALUES ('.AAPL150117C600');
INSERT INTO "RTD"."OPTION_LIST_TOS" ("CODE") VALUES ('.AAPL150117P500');
INSERT INTO "RTD"."OPTION_LIST_TOS" ("CODE") VALUES ('.AAPL150117P600');
INSERT INTO "RTD"."OPTION_LIST_YAHOO" ("CODE") VALUES ('AAPL150117C00500000');
INSERT INTO "RTD"."OPTION_LIST_YAHOO" ("CODE") VALUES ('AAPL150117C00600000');
INSERT INTO "RTD"."OPTION_LIST_YAHOO" ("CODE") VALUES ('AAPL150117P00500000');
INSERT INTO "RTD"."OPTION_LIST_YAHOO" ("CODE") VALUES ('AAPL150117P00600000');
INSERT INTO "RTD"."QUOTE_LIST_ES" ("CODE") VALUES ('AAPL');
INSERT INTO "RTD"."QUOTE_LIST_ES" ("CODE") VALUES ('GOOG');
INSERT INTO "RTD"."QUOTE_LIST_ES" ("CODE") VALUES ('MSFT');
INSERT INTO "RTD"."QUOTE_LIST_ES" ("CODE") VALUES ('ORCL');
INSERT INTO "RTD"."QUOTE_LIST_ES" ("CODE") VALUES ('FB');
INSERT INTO "RTD"."QUOTE_LIST_ES" ("CODE") VALUES ('LNKD');
INSERT INTO "RTD"."QUOTE_LIST_ES" ("CODE") VALUES ('YHOO');
INSERT INTO "RTD"."QUOTE_LIST_STOCKS" ("CODE") VALUES ('AAPL');
INSERT INTO "RTD"."QUOTE_LIST_STOCKS" ("CODE") VALUES ('GOOG');
INSERT INTO "RTD"."QUOTE_LIST_STOCKS" ("CODE") VALUES ('MSFT');
INSERT INTO "RTD"."QUOTE_LIST_STOCKS" ("CODE") VALUES ('ORCL');
INSERT INTO "RTD"."QUOTE_LIST_STOCKS" ("CODE") VALUES ('FB');
INSERT INTO "RTD"."QUOTE_LIST_STOCKS" ("CODE") VALUES ('LNKD');
INSERT INTO "RTD"."QUOTE_LIST_STOCKS" ("CODE") VALUES ('YHOO');
INSERT INTO "RTD"."QUOTE_LIST_TOS" ("CODE") VALUES ('/ES');
INSERT INTO "RTD"."QUOTE_LIST_TOS" ("CODE") VALUES ('AAPL');
INSERT INTO "RTD"."QUOTE_LIST_TOS" ("CODE") VALUES ('GOOG');
INSERT INTO "RTD"."QUOTE_LIST_TOS" ("CODE") VALUES ('MSFT');
INSERT INTO "RTD"."QUOTE_LIST_TOS" ("CODE") VALUES ('ORCL');
INSERT INTO "RTD"."QUOTE_LIST_TOS" ("CODE") VALUES ('FB');
INSERT INTO "RTD"."QUOTE_LIST_TOS" ("CODE") VALUES ('LNKD');
INSERT INTO "RTD"."QUOTE_LIST_TOS" ("CODE") VALUES ('YHOO');
INSERT INTO "RTD"."QUOTE_LIST_TWS" ("CODE") VALUES ('AAPL');
INSERT INTO "RTD"."QUOTE_LIST_TWS" ("CODE") VALUES ('GOOG');
INSERT INTO "RTD"."QUOTE_LIST_TWS" ("CODE") VALUES ('MSFT');
INSERT INTO "RTD"."QUOTE_LIST_TWS" ("CODE") VALUES ('ORCL');
INSERT INTO "RTD"."QUOTE_LIST_TWS" ("CODE") VALUES ('FB');
INSERT INTO "RTD"."QUOTE_LIST_TWS" ("CODE") VALUES ('LNKD');
INSERT INTO "RTD"."QUOTE_LIST_TWS" ("CODE") VALUES ('YHOO');
INSERT INTO "RTD"."QUOTE_LIST_TWS" ("CODE") VALUES ('AAPL_OPT_20150116_500_C_100_SMART_USD_~');
INSERT INTO "RTD"."QUOTE_LIST_TWS" ("CODE") VALUES ('AAPL_OPT_20150116_600_C_100_SMART_USD_~');
INSERT INTO "RTD"."QUOTE_LIST_TWS" ("CODE") VALUES ('AAPL_OPT_20150116_500_P_100_SMART_USD_~');
INSERT INTO "RTD"."QUOTE_LIST_TWS" ("CODE") VALUES ('AAPL_OPT_20150116_600_P_100_SMART_USD_~');
INSERT INTO "RTD"."QUOTE_LIST_VFX" ("CODE") VALUES ('EUR_USD');
INSERT INTO "RTD"."QUOTE_LIST_VFX" ("CODE") VALUES ('GBP_USD');
INSERT INTO "RTD"."QUOTE_LIST_VFX" ("CODE") VALUES ('USD_CHF');
INSERT INTO "RTD"."QUOTE_LIST_VFX" ("CODE") VALUES ('USD_JPY');
INSERT INTO "RTD"."QUOTE_LIST_YAHOO" ("CODE") VALUES ('AAPL');
INSERT INTO "RTD"."QUOTE_LIST_YAHOO" ("CODE") VALUES ('GOOG');
INSERT INTO "RTD"."QUOTE_LIST_YAHOO" ("CODE") VALUES ('MSFT');
INSERT INTO "RTD"."QUOTE_LIST_YAHOO" ("CODE") VALUES ('ORCL');
INSERT INTO "RTD"."QUOTE_LIST_YAHOO" ("CODE") VALUES ('FB');
INSERT INTO "RTD"."QUOTE_LIST_YAHOO" ("CODE") VALUES ('LNKD');
INSERT INTO "RTD"."QUOTE_LIST_YAHOO" ("CODE") VALUES ('YHOO');

CREATE VIEW "RTDXLS"."FUNDAMENTALS_DAY_HISTORY_YAHOO"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , MAX(t."LAST_TRADE_DATE") AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"LastTradeTime")' AS "LastTradeTime"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"DaysRange")' AS "DaysRange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PrevClose")' AS "PrevClose"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"ShortRatio")' AS "ShortRatio"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"YearHigh")' AS "YearHigh"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"YearLow")' AS "YearLow"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"YearRange")' AS "YearRange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"ChangeFromYearHigh")' AS "ChangeFromYearHigh"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"ChangeFromYearLow")' AS "ChangeFromYearLow"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PercentChangeFromYearHigh")' AS "PercentChangeFromYearHigh"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PercentChangeFromYearLow")' AS "PercentChangeFromYearLow"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"MA50")' AS "MA50"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"MA200")' AS "MA200"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"ChangeFromMA50")' AS "ChangeFromMA50"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"ChangeFromMA200")' AS "ChangeFromMA200"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PercentChangeFromMA50")' AS "PercentChangeFromMA50"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PercentChangeFromMA200")' AS "PercentChangeFromMA200"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"AverageDailyVolume")' AS "AverageDailyVolume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"OneYearTargetPrice")' AS "OneYearTargetPrice"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PE")' AS "PE"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PEG")' AS "PEG"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"EPSEstCurrentYear")' AS "EPSEstCurrentYear"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"EPSEstNextQuarter")' AS "EPSEstNextQuarter"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"EPSEstNextYear")' AS "EPSEstNextYear"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"EarningsShare")' AS "EarningsShare"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"MarketCap")' AS "MarketCap"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"DividendYield")' AS "DividendYield"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"DividendShare")' AS "DividendShare"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"ExDividendDate")' AS "ExDividendDate"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"DividendPayDate")' AS "DividendPayDate"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"BookValue")' AS "BookValue"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PriceBook")' AS "PriceBook"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PriceSales")' AS "PriceSales"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PriceEPSEstCurrentYear")' AS "PriceEPSEstCurrentYear"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"PriceEPSEstNextYear")' AS "PriceEPSEstNextYear"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"EBITDA")' AS "EBITDA"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"CompanyName")' AS "CompanyName"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"StockExchange")' AS "StockExchange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"Commission")' AS "Commission"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"Notes")' AS "Notes"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_day_history_yahoo",[Symbol],[Date],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."FUNDAMENTALS_DAY_HISTORY_YAHOO" t
GROUP BY
    t."SYMBOL";

CREATE VIEW "RTDXLS"."FUNDAMENTALS_YAHOO"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"LastTradeDate")' AS "LastTradeDate"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"LastTradeTime")' AS "LastTradeTime"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"DaysRange")' AS "DaysRange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PrevClose")' AS "PrevClose"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"ShortRatio")' AS "ShortRatio"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"YearHigh")' AS "YearHigh"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"YearLow")' AS "YearLow"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"YearRange")' AS "YearRange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"ChangeFromYearHigh")' AS "ChangeFromYearHigh"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"ChangeFromYearLow")' AS "ChangeFromYearLow"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PercentChangeFromYearHigh")' AS "PercentChangeFromYearHigh"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PercentChangeFromYearLow")' AS "PercentChangeFromYearLow"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"MA50")' AS "MA50"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"MA200")' AS "MA200"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"ChangeFromMA50")' AS "ChangeFromMA50"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"ChangeFromMA200")' AS "ChangeFromMA200"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PercentChangeFromMA50")' AS "PercentChangeFromMA50"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PercentChangeFromMA200")' AS "PercentChangeFromMA200"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"AverageDailyVolume")' AS "AverageDailyVolume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"OneYearTargetPrice")' AS "OneYearTargetPrice"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PE")' AS "PE"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PEG")' AS "PEG"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"EPSEstCurrentYear")' AS "EPSEstCurrentYear"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"EPSEstNextQuarter")' AS "EPSEstNextQuarter"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"EPSEstNextYear")' AS "EPSEstNextYear"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"EarningsShare")' AS "EarningsShare"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"MarketCap")' AS "MarketCap"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"DividendYield")' AS "DividendYield"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"DividendShare")' AS "DividendShare"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"ExDividendDate")' AS "ExDividendDate"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"DividendPayDate")' AS "DividendPayDate"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"BookValue")' AS "BookValue"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PriceBook")' AS "PriceBook"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PriceSales")' AS "PriceSales"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PriceEPSEstCurrentYear")' AS "PriceEPSEstCurrentYear"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"PriceEPSEstNextYear")' AS "PriceEPSEstNextYear"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"EBITDA")' AS "EBITDA"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"CompanyName")' AS "CompanyName"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"StockExchange")' AS "StockExchange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"Commission")' AS "Commission"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"Notes")' AS "Notes"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","fundamentals_yahoo",[Symbol],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."FUNDAMENTALS_YAHOO" t;

CREATE VIEW "RTDXLS"."OPTION_DAY_HISTORY_TOS"
AS

SELECT
    t."CODE" AS "Code"
    , MAX(t."DATE") AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Description")' AS "Description"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"LastSize")' AS "LastSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"LastX")' AS "LastX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Mark")' AS "Mark"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"MarkChange")' AS "MarkChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"MarkPercentChange")' AS "MarkPercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"BidSize")' AS "BidSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"AskSize")' AS "AskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"BidAskSize")' AS "BidAskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"BidX")' AS "BidX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"AskX")' AS "AskX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Close")' AS "Close"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"OpenInt")' AS "OpenInt"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"ImpliedVol")' AS "ImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Delta")' AS "Delta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Gamma")' AS "Gamma"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Theta")' AS "Theta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Vega")' AS "Vega"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Rho")' AS "Rho"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Extrinsic")' AS "Extrinsic"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"Intrinsic")' AS "Intrinsic"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"ProbabilityITM")' AS "ProbabilityITM"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"ProbabilityOTM")' AS "ProbabilityOTM"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"ProbabilityTouch")' AS "ProbabilityTouch"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"CoveredReturn")' AS "CoveredReturn"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"MaxCoveredReturn")' AS "MaxCoveredReturn"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tos",[Code],[Date],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."OPTION_DAY_HISTORY_TOS" t
GROUP BY
    t."CODE";

CREATE VIEW "RTDXLS"."OPTION_DAY_HISTORY_TWS"
AS

SELECT
    t."CODE" AS "Code"
    , MAX(t."DATE") AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"LastSize")' AS "LastSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"BidSize")' AS "BidSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"AskSize")' AS "AskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"Close")' AS "Close"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"UnderlyingPrice")' AS "UnderlyingPrice"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"ModelPrice")' AS "ModelPrice"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"ImpliedVol")' AS "ImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"BidImpliedVol")' AS "BidImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"AskImpliedVol")' AS "AskImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"LastImpliedVol")' AS "LastImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"BidDelta")' AS "BidDelta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"AskDelta")' AS "AskDelta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"LastDelta")' AS "LastDelta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"Delta")' AS "Delta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"Gamma")' AS "Gamma"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"Theta")' AS "Theta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"Vega")' AS "Vega"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"pvDividend")' AS "pvDividend"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_tws",[Code],[Date],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."OPTION_DAY_HISTORY_TWS" t
GROUP BY
    t."CODE";

CREATE VIEW "RTDXLS"."OPTION_DAY_HISTORY_YAHOO"
AS

SELECT
    t."CODE" AS "Code"
    , MAX(t."DATE") AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"OptionCode")' AS "OptionCode"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"Symbol")' AS "Symbol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"OptionSymbol")' AS "OptionSymbol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"ExpDate")' AS "ExpDate"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"Strike")' AS "Strike"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"Type")' AS "Type"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"Mark")' AS "Mark"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"OpenInt")' AS "OpenInt"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","option_day_history_yahoo",[Code],[Date],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."OPTION_DAY_HISTORY_YAHOO" t
GROUP BY
    t."CODE";

CREATE VIEW "RTDXLS"."OPTIONS_TOS"
AS

SELECT
    t."CODE" AS "Code"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Date")' AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Description")' AS "Description"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"LastSize")' AS "LastSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"LastX")' AS "LastX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Mark")' AS "Mark"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"MarkChange")' AS "MarkChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"MarkPercentChange")' AS "MarkPercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"BidSize")' AS "BidSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"AskSize")' AS "AskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"BidAskSize")' AS "BidAskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"BidX")' AS "BidX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"AskX")' AS "AskX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Close")' AS "Close"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"OpenInt")' AS "OpenInt"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"ImpliedVol")' AS "ImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Delta")' AS "Delta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Gamma")' AS "Gamma"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Theta")' AS "Theta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Vega")' AS "Vega"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Rho")' AS "Rho"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Extrinsic")' AS "Extrinsic"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"Intrinsic")' AS "Intrinsic"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"ProbabilityITM")' AS "ProbabilityITM"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"ProbabilityOTM")' AS "ProbabilityOTM"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"ProbabilityTouch")' AS "ProbabilityTouch"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"CoveredReturn")' AS "CoveredReturn"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"MaxCoveredReturn")' AS "MaxCoveredReturn"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tos",[Code],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."OPTIONS_TOS" t;

CREATE VIEW "RTDXLS"."OPTIONS_TWS"
AS

SELECT
    t."CODE" AS "Code"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Date")' AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"LastSize")' AS "LastSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"BidSize")' AS "BidSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"AskSize")' AS "AskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Close")' AS "Close"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"UnderlyingPrice")' AS "UnderlyingPrice"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"ModelPrice")' AS "ModelPrice"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"ImpliedVol")' AS "ImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"BidImpliedVol")' AS "BidImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"AskImpliedVol")' AS "AskImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"LastImpliedVol")' AS "LastImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"BidDelta")' AS "BidDelta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"AskDelta")' AS "AskDelta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"LastDelta")' AS "LastDelta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Delta")' AS "Delta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Gamma")' AS "Gamma"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Theta")' AS "Theta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"Vega")' AS "Vega"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"pvDividend")' AS "pvDividend"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_tws",[Code],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."OPTIONS_TWS" t;

CREATE VIEW "RTDXLS"."OPTIONS_YAHOO"
AS

SELECT
    t."CODE" AS "Code"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"Date")' AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"OptionCode")' AS "OptionCode"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"Symbol")' AS "Symbol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"OptionSymbol")' AS "OptionSymbol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"ExpDate")' AS "ExpDate"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"Strike")' AS "Strike"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"Type")' AS "Type"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"Mark")' AS "Mark"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"OpenInt")' AS "OpenInt"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","options_yahoo",[Code],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."OPTIONS_YAHOO" t;

CREATE VIEW "RTDXLS"."QUOTE_DAY_HISTORY_ES"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , MAX(t."DATE") AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"BidSize")' AS "BidSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"AskSize")' AS "AskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"OpenInt")' AS "OpenInt"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"TradePrice")' AS "TradePrice"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_es",[Symbol],[Date],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."QUOTE_DAY_HISTORY_ES" t
GROUP BY
    t."SYMBOL";

CREATE VIEW "RTDXLS"."QUOTE_DAY_HISTORY_TOS"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , MAX(t."DATE") AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Description")' AS "Description"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"LastSize")' AS "LastSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"LastX")' AS "LastX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Mark")' AS "Mark"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"MarkChange")' AS "MarkChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"MarkPercentChange")' AS "MarkPercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"BidSize")' AS "BidSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"AskSize")' AS "AskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"BidAskSize")' AS "BidAskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"BidX")' AS "BidX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"AskX")' AS "AskX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"StrengthMeter")' AS "StrengthMeter"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Close")' AS "Close"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"OpenInt")' AS "OpenInt"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"ImpliedVol")' AS "ImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"VolIndex")' AS "VolIndex"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"FrontVol")' AS "FrontVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"BackVol")' AS "BackVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"WeightedBackVol")' AS "WeightedBackVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"VolDiff")' AS "VolDiff"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"PutCallRatio")' AS "PutCallRatio"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"CallVolumeIndex")' AS "CallVolumeIndex"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"PutVolumeIndex")' AS "PutVolumeIndex"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"OptionVolumeIndex")' AS "OptionVolumeIndex"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"FrontExpectedMove")' AS "FrontExpectedMove"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"BackExpectedMove")' AS "BackExpectedMove"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"ExpectedMoveDiff")' AS "ExpectedMoveDiff"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Beta")' AS "Beta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"High52")' AS "High52"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Low52")' AS "Low52"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"PE")' AS "PE"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"EPS")' AS "EPS"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"MarketCap")' AS "MarketCap"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"Shares")' AS "Shares"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"DividendYield")' AS "DividendYield"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"DividendShare")' AS "DividendShare"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tos",[Symbol],[Date],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."QUOTE_DAY_HISTORY_TOS" t
GROUP BY
    t."SYMBOL";

CREATE VIEW "RTDXLS"."QUOTE_DAY_HISTORY_TWS"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , MAX(t."DATE") AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"LastSize")' AS "LastSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"BidSize")' AS "BidSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"AskSize")' AS "AskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"Close")' AS "Close"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_tws",[Symbol],[Date],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."QUOTE_DAY_HISTORY_TWS" t
GROUP BY
    t."SYMBOL";

CREATE VIEW "RTDXLS"."QUOTE_DAY_HISTORY_VFX"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , MAX(t."DATE") AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_vfx",[Symbol],[Date],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_vfx",[Symbol],[Date],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_vfx",[Symbol],[Date],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_vfx",[Symbol],[Date],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_vfx",[Symbol],[Date],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_vfx",[Symbol],[Date],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_vfx",[Symbol],[Date],"Close")' AS "Close"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_vfx",[Symbol],[Date],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_vfx",[Symbol],[Date],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_vfx",[Symbol],[Date],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_vfx",[Symbol],[Date],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."QUOTE_DAY_HISTORY_VFX" t
GROUP BY
    t."SYMBOL";

CREATE VIEW "RTDXLS"."QUOTE_DAY_HISTORY_YAHOO"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , MAX(t."LAST_TRADE_DATE") AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_yahoo",[Symbol],[Date],"LastTradeTime")' AS "LastTradeTime"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_yahoo",[Symbol],[Date],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_yahoo",[Symbol],[Date],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_yahoo",[Symbol],[Date],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_yahoo",[Symbol],[Date],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_yahoo",[Symbol],[Date],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_yahoo",[Symbol],[Date],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_yahoo",[Symbol],[Date],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_yahoo",[Symbol],[Date],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quote_day_history_yahoo",[Symbol],[Date],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."QUOTE_DAY_HISTORY_YAHOO" t
GROUP BY
    t."SYMBOL";

CREATE VIEW "RTDXLS"."QUOTES_ES"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"Date")' AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"BidSize")' AS "BidSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"AskSize")' AS "AskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"OpenInt")' AS "OpenInt"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"TradePrice")' AS "TradePrice"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_es",[Symbol],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."QUOTES_ES" t;

CREATE VIEW "RTDXLS"."QUOTES_TOS"
AS

SELECT
    t."SYMBOL"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Date")' AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Description")' AS "Description"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"LastSize")' AS "LastSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"LastX")' AS "LastX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Mark")' AS "Mark"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"MarkChange")' AS "MarkChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"MarkPercentChange")' AS "MarkPercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"BidSize")' AS "BidSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"AskSize")' AS "AskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"BidAskSize")' AS "BidAskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"BidX")' AS "BidX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"AskX")' AS "AskX"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"StrengthMeter")' AS "StrengthMeter"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Close")' AS "Close"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"OpenInt")' AS "OpenInt"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"ImpliedVol")' AS "ImpliedVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"VolIndex")' AS "VolIndex"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"FrontVol")' AS "FrontVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"BackVol")' AS "BackVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"WeightedBackVol")' AS "WeightedBackVol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"VolDiff")' AS "VolDiff"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"PutCallRatio")' AS "PutCallRatio"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"CallVolumeIndex")' AS "CallVolumeIndex"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"PutVolumeIndex")' AS "PutVolumeIndex"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"OptionVolumeIndex")' AS "OptionVolumeIndex"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"FrontExpectedMove")' AS "FrontExpectedMove"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"BackExpectedMove")' AS "BackExpectedMove"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"ExpectedMoveDiff")' AS "ExpectedMoveDiff"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Beta")' AS "Beta"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"High52")' AS "High52"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Low52")' AS "Low52"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"PE")' AS "PE"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"EPS")' AS "EPS"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"MarketCap")' AS "MarketCap"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"Shares")' AS "Shares"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"DividendYield")' AS "DividendYield"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"DividendShare")' AS "DividendShare"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tos",[Symbol],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."QUOTES_TOS" t;

CREATE VIEW "RTDXLS"."QUOTES_TWS"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"Date")' AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"LastSize")' AS "LastSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"BidSize")' AS "BidSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"AskSize")' AS "AskSize"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"Close")' AS "Close"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_tws",[Symbol],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."QUOTES_TWS" t;

CREATE VIEW "RTDXLS"."QUOTES_VFX"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"Date")' AS "Date"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"Time")' AS "Time"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"Bid")' AS "Bid"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"Ask")' AS "Ask"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"Close")' AS "Close"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_vfx",[Symbol],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."QUOTES_VFX" t;

CREATE VIEW "RTDXLS"."QUOTES_YAHOO"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_yahoo",[Symbol],"LastTradeDate")' AS "LastTradeDate"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_yahoo",[Symbol],"LastTradeTime")' AS "LastTradeTime"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_yahoo",[Symbol],"Last")' AS "Last"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_yahoo",[Symbol],"Change")' AS "Change"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_yahoo",[Symbol],"PercentChange")' AS "PercentChange"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_yahoo",[Symbol],"Open")' AS "Open"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_yahoo",[Symbol],"High")' AS "High"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_yahoo",[Symbol],"Low")' AS "Low"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_yahoo",[Symbol],"Volume")' AS "Volume"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_yahoo",[Symbol],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
    , '=RTD("gartle.rtd",,"rtd-nuodb","quotes_yahoo",[Symbol],"RTD_LastMessage")' AS "RTD_LastMessage"
FROM
    "RTD"."QUOTES_YAHOO" t;

CREATE VIEW "RTDXLS"."STOCKS_YAHOO"
AS

SELECT
    t."SYMBOL" AS "Symbol"
    , '=RTD("gartle.rtd",,"rtd-nuodb","stocks_yahoo",[Symbol],"CompanyName")' AS "CompanyName"
    , '=RTD("gartle.rtd",,"rtd-nuodb","stocks_yahoo",[Symbol],"Sector")' AS "Sector"
    , '=RTD("gartle.rtd",,"rtd-nuodb","stocks_yahoo",[Symbol],"Industry")' AS "Industry"
    , '=RTD("gartle.rtd",,"rtd-nuodb","stocks_yahoo",[Symbol],"FullTimeEmployees")' AS "FullTimeEmployees"
    , '=RTD("gartle.rtd",,"rtd-nuodb","stocks_yahoo",[Symbol],"TradeStart")' AS "TradeStart"
    , '=RTD("gartle.rtd",,"rtd-nuodb","stocks_yahoo",[Symbol],"TradeEnd")' AS "TradeEnd"
    , '=RTD("gartle.rtd",,"rtd-nuodb","stocks_yahoo",[Symbol],"LastUpdateTimeStamp")' AS "LastUpdateTimeStamp"
FROM
    "RTD"."STOCKS_YAHOO" t;

CREATE VIEW "RTDXLS"."REAL_TIME_VIEWS"
AS

SELECT
    t.SCHEMA AS TABLE_SCHEMA
    , t.TABLENAME AS TABLE_NAME
    , 'VIEW' AS "TABLE_TYPE"
    , NULL AS INSERT_PROCEDURE
    , NULL AS UPDATE_PROCEDURE
    , NULL AS DELETE_PROCEDURE
FROM
    SYSTEM.TABLES t
WHERE
    t.SCHEMA = 'RTDXLS'
    AND t."TYPE" = 'VIEW'
    AND t.TABLENAME NOT IN ('REAL_TIME_VIEWS');

-- print RTD objects have been created
